export interface RouterHistory {
    location: HistoryLocation;
    subscribe: (cb: () => void) => () => void;
    push: (path: string, state?: any) => void;
    replace: (path: string, state?: any) => void;
    go: (index: number) => void;
    back: () => void;
    forward: () => void;
    createHref: (href: string) => string;
    block: (blockerFn: BlockerFn) => () => void;
    flush: () => void;
}
export interface HistoryLocation extends ParsedPath {
    state: HistoryState;
}
export interface ParsedPath {
    href: string;
    pathname: string;
    search: string;
    hash: string;
}
export interface HistoryState {
    key: string;
    __tempLocation?: HistoryLocation;
    __tempKey?: string;
}
type BlockerFn = (retry: () => void, cancel: () => void) => void;
/**
 * Creates a history object that can be used to interact with the browser's
 * navigation. This is a lightweight API wrapping the browser's native methods.
 * It is designed to work with TanStack Router, but could be used as a standalone API as well.
 * IMPORTANT: This API implements history throttling via a microtask to prevent
 * excessive calls to the history API. In some browsers, calling history.pushState or
 * history.replaceState in quick succession can cause the browser to ignore subsequent
 * calls. This API smooths out those differences and ensures that your application
 * state will *eventually* match the browser state. In most cases, this is not a problem,
 * but if you need to ensure that the browser state is up to date, you can use the
 * `history.flush` method to immediately flush all pending state changes to the browser URL.
 * @param opts
 * @param opts.getHref A function that returns the current href (path + search + hash)
 * @param opts.createHref A function that takes a path and returns a href (path + search + hash)
 * @returns A history instance
 */
export declare function createBrowserHistory(opts?: {
    getHref?: () => string;
    createHref?: (path: string) => string;
}): RouterHistory;
export declare function createHashHistory(): RouterHistory;
export declare function createMemoryHistory(opts?: {
    initialEntries: string[];
    initialIndex?: number;
}): RouterHistory;
export {};
